<?php

namespace Portfoliya_Pro\Controllers;

use Portfoliya\Models\User;
use Portfoliya_Pro\Models\Contributor;

class ContributorController {
	const PREREQUISITES = array(
		'updateContributorStatus' => array(),
		'fetchContributorList'    => array(
			'role' => 'administrator'
		)
	);

	/**
	 * Update contributor status for a user
	 *
	 * @param string $status
	 * @param integer $user_id
	 * @param boolean $is_admin
	 * @return void
	 */
	public static function updateContributorStatus( string $status = '', int $user_id = 0, bool $is_admin = false ) {
		if ( ! $is_admin ) {
			// Set the current user ID as the request came from user dashboard
			$user_id = get_current_user_id();
		} else {
			// If acting like admin, then verify privilege
			if ( ! User::hasAdministrativeRole( get_current_user_id() ) ) {
				wp_send_json_error( array( 'message' => __( 'You are not authorized!', 'portfoliya' ) ) );
			}
		}

		// Check if valid status
		if ( ! empty( $status ) && ! in_array( $status, Contributor::CONTRIBUTOR_STATUSES ) ) {
			wp_send_json_error( array( 'message' => __( 'Invalid status', 'portfoliya' ) ) );
		}

		$current_status = Contributor::getStatus( $user_id );

		if ( ! $is_admin ) {

			// Cancel the request as long as it is in pending mode.
			if ( empty( $status ) && $current_status === 'pending' ) {
				$status = null;
				
			} else if ( $status !== 'pending' || ! empty( $current_status ) ) {
				wp_send_json_error( array( 'message' => __( 'You can not change the application status currently!', 'portfoliya' ) ) );
			}
		}

		Contributor::updateStatus( $user_id, $status );

		wp_send_json_success( array( 'contributor_status' => Contributor::getStatus( $user_id ) ) );
	}

	/**
	 * Get contributor list to show in admin dashboard
	 *
	 * @param integer $page
	 * @param string $status
	 * @param string $user_email
	 * @return void
	 */
	public static function fetchContributorList( int $page = 1, string $status ='', string $search = '' ) {

		$args = array(
			'page'   => $page,
			'status' => $status,
			'search' => $search
		);

		$contributors = Contributor::getContributors( $args );
		$segmentation = Contributor::getContributors( $args, true );

		wp_send_json_success(
			array( 
				'contributors' => $contributors,
				'segmentation' => $segmentation 
			) 
		);
	}
}
