<?php
/**
 * @package portfoliya
 */

namespace Portfoliya_Pro\Controllers;

use Portfoliya\Models\User;
use Portfoliya_Pro\Models\Licensing;
use Portfoliya_Pro\Models\Sale;

class LicenseController {
	const PREREQUISITES = array(
		'licenseKeyAction' => array(),
		'getMyOrders' => array()
	);
	
	/**
	 * Get license key and sale info
	 *
	 * @param integer $sale_id
	 * @return void
	 */
	public static function licenseKeyAction( int $sale_id, string $license_action = '', int $license_id = 0 ) {

		$sale = Sale::getSalePlan( $sale_id );

		if ( empty( $sale ) ) {
			wp_send_json_error( array( 'message' => __( 'Sale not found', 'portfoliya' ) ) );
		}

		// Check if the sale was purchased by this customer, or current user has administrative role
		if ( $sale['customer_id'] != get_current_user_id() && ! User::hasAdministrativeRole( get_current_user_id() ) ) {
			wp_send_json_error( array( 'message' => __( 'You are not authorized!', 'portfoliya' ) ) );
		}

		switch ( $license_action ) {
			case 'add' :
				// Check if limit reached
				if ( ! empty( $sale['license_or_content_limit'] ) && $sale['license_or_content_limit'] <= Licensing::getKeyCount( $sale_id ) ) {
					wp_send_json_error( array( 'message' => __( 'You have reached the limit', 'portfoliya' ) ) );
				}

				// Now add new key
				Licensing::addNewLicenseKey( $sale );
				break;

			case 'delete' :
				Licensing::deleteKey( $license_id, $sale_id );
				break;

			case 'regenerate' :
				Licensing::regenerateLicenseKey( $sale, $license_id );
				break;
		}
		
		wp_send_json_success(
			array( 
				'license_keys' => Licensing::getLicenseKeys( $sale['sale_id'], null, null, $sale['customer_id'] ),
				'sale'         => $sale,
				'renewals'     => Sale::getRenewalOrders( $sale['sale_id'] )
			)
		);
	}

	/**
	 * Get the own WooCommerce Orders no matter what was purchased
	 *
	 * @return void
	 */
	public static function getMyOrders() {
		
		$orders = wc_get_orders( array(
			'customer' => get_current_user_id(),
			'limit'    => -1,
		) );

		$order_array = array();

		// Loop through orders and get details
		foreach ( $orders as $order ) {
			$order_array[] = Sale::getOrderDetails( $order );
        }

		wp_send_json_success( array( 'orders' => $order_array ) );
	}
}
