<?php

namespace Portfoliya_Pro\Controllers;

use Portfoliya_Pro\Models\Message;
use Portfoliya\Models\User;

class MessagingController {

	const PREREQUISITES = array(
		'sendMessage' => array(
		),
		'fetchMessages' => array(
		),
		'fetchThreads' => array(
		),
	);

	private static function checkConnection( $peer_id ) {
		return;
	}

	public static function sendMessage( int $recipient_id, string $message, int $later_than = 0 ) {

		self::checkConnection( $recipient_id );

		// Send message
		$current_user_id = get_current_user_id();
		$message_id = Message::sendMessage( $current_user_id, $recipient_id, $message );

		// Error response if sending fails
		if ( ! $message_id || ! is_numeric( $message_id ) ) {
			wp_send_json_error(
				array(
					'message' => 'Could not send message'
				)
			);
		}
		
		// Get updated messages
		$messages = Message::getMessages( 
			$current_user_id, 
			$recipient_id, 
			true, 
			array( 'later_than' => $later_than )
		);

		wp_send_json_success(
			array(
				'messages' => $messages
			)
		);
	}

	public static function fetchMessages( int $recipient_id, int $older_than = 0, int $later_than = 0 ) {

		if ( User::isConnectionBlocked( $recipient_id, get_current_user_id() ) ) {
			wp_send_json_error( array( 'message' => __( 'The user is not reacable!', 'mateup' ) ) );
		}

		$user = get_userdata( $recipient_id );
		if ( empty( $user ) ) {
			wp_send_json_error( array( 'message' => __( 'User not found', 'portfoliya' ) ) );
		}

		$response   = array(
			'peer' => array(
				'user_id'      => $recipient_id,
				'display_name' => $user->display_name,
				'avatar_url'   => get_avatar_url( $recipient_id )
			),
		);

		$response['messages'] = Message::getMessages( 
			get_current_user_id(), 
			$recipient_id, 
			true, 
			array( 
				'older_than' => $older_than,
				'later_than' => $later_than
			)
		);

		wp_send_json_success( $response );
	}

	public static function fetchThreads() {
		wp_send_json_success( array( 'threads' => Message::getMessageThreads( get_current_user_id() ) ) );
	}
}
