<?php

namespace Portfoliya_Pro;

use SolidieLib\_Array;
use Portfoliya\Main as MainFree;
use Portfoliya\Models\User as ModelsUser;
use Portfoliya_Pro\Setup\Content;
use Portfoliya_Pro\Setup\Dashboard;
use Portfoliya_Pro\Setup\RestAPI;
use Portfoliya_Pro\Setup\Downloader;
use Portfoliya_Pro\Setup\Route;
use Portfoliya_Pro\Setup\Scripts;
use Portfoliya_Pro\Setup\User;
use Portfoliya_Pro\Setup\WooCommerce;
use SolidieLib\Updater;
use WooCommerce as WC;

use Portfoliya_Pro\Controllers\ContentController;
use Portfoliya_Pro\Controllers\ContributorController;
use Portfoliya_Pro\Controllers\EarningController;
use Portfoliya_Pro\Controllers\LicenseController;
use Portfoliya_Pro\Controllers\MessagingController;
use Portfoliya_Pro\Controllers\UserController;
use Portfoliya_Pro\Setup\Socket;
use SolidieLib\Dispatcher;

class Main {

	/**
	 * Configs array
	 *
	 * @var object
	 * @property string $plugin_name
	 * @property string $description
	 * @property string $version
	 * @property string $author
	 * @property string $file
	 * @property string $dir
	 * @property string $url
	 * @property string $dist_url
	 */
	public static $configs;

	/**
	 * Initialize Plugin
	 * 
	 * @param object $configs
	 * 
	 * @return void
	 */
	public function init( object $configs ) {
		self::$configs = $configs;
		$this->loadPro();
	}

	/**
	 * Load Portfoliya Pro functionalities after loaded free
	 *
	 * @return void
	 */
	public function loadPro(){

		// Load app
		new Route();
		new Scripts();
		new Content();
		new Dashboard();
		new WooCommerce();
		new User();
		new Socket();
		new RestAPI();
		new Downloader();

		// Load license page
		$updater = new Updater(
			array(
				'app_pointer'      => plugin_basename( self::$configs->file ),
				'app_id'           => basename( self::$configs->dir ),
				'app_label'        => __( 'Portfoliya', 'portfoliya' ),
				'app_version'      => Main::$configs->version,
				'app_url'          => Main::$configs->url,
				'api_endpoint'     => ( 'development' === Main::$configs->mode ? 'http://localhost:10019' : 'https://portfoliya.com' ) . RestAPI::getAPIPath(),
				'root_menu'        => MainFree::$configs->root_menu_slug,
				'user_role'        => ModelsUser::getPortfoliyaAdminRole(),
				'screen_label'     => __( 'Portfoliya License', 'portfoliya' ),
				'logo_url'         => MainFree::$configs->dist_url . 'libraries/menu-icon.svg',
				'contact_url'      => 'https://portfoliya.com/#contact',
				'license_find_url' => 'https://portfoliya.com/dashboard/my-purchases/',
			)
		);
		
		new Dispatcher(
			MainFree::$configs->app_id,
			array(
				ContentController::class,
				LicenseController::class,
				UserController::class,
				EarningController::class,
				ContributorController::class,
				MessagingController::class,
				$updater
			)
		);
	}

	function showDependencyError() {
		if ( ! class_exists( MainFree::class ) ) {

			$action = self::getPluginAction( 'portfoliya/portfoliya.php', __( 'Portfoliya Core', 'portfoliya' ) );

			?>
			<div class="notice notice-warning">
				<p>
					<?php 
						echo sprintf(
							esc_html__( 'Portfoliya Pro requires Portfoliya Core. %s.', 'portfoliya' ),
							'<a href="' . esc_url( $action['action_link'] ) . '">' . $action['action_label'] . '</a>'
						); 
					?>
				</p>
			</div>
			<?php
		}

		if ( ! class_exists( WC::class ) ) {

			$action = self::getPluginAction( 'woocommerce/woocommerce.php', __( 'WooCommerce', 'portfoliya' ) );

			?>
			<div class="notice notice-warning">
				<p>
					<?php
						echo sprintf(
							esc_html__( 'Portfoliya Pro requires WooCommerce for content monetization. %s.', 'portfoliya' ), 
							'<a href="' . esc_url( $action['action_link'] ) . '">' . $action['action_label'] . '</a>' 
						); 
					?>
				</p>
			</div>
			<?php
		}
	}

	public function freeInstallLink( array $actions ) {
		
		$action = self::getPluginAction( 'portfoliya/portfoliya.php', __( 'Portfoliya Core', 'portfoliya' ) );
		if ( ! empty( $action ) ) {
			$actions['portfoliya_action_link'] = '<a href="' . esc_url( $action['action_link'] ) . '">
				<span style="color: #ff7742; font-weight: bold;">' .
					$action['action_label'] .
				'</span>
			</a>';
		}
		
		return $actions;
	}

	/**
	 * Get plugin action label and link
	 *
	 * @param string $plugin_id
	 * @param string $label
	 * 
	 * @return array|null
	 */
	public static function getPluginAction( string $plugin_id, string $label ) {

		$action      = null;
		$plugin_path = trailingslashit( WP_PLUGIN_DIR ) . $plugin_id;

		if ( ! is_plugin_active( $plugin_id ) ) {
			
			if ( file_exists( $plugin_path ) ) {

				$action = array(
					'action_label' => sprintf( __( 'Activate %s', 'portfoliya' ), $label ),
					'action_link'  => add_query_arg(
						array(
							'action'   => 'activate',
							'plugin'   => $plugin_id,
							'_wpnonce' => wp_create_nonce( 'activate-plugin_' . $plugin_id ),
						),
						admin_url( 'plugins.php' )
					)
				);
			} else {

				$action = array(
					'action_label' => sprintf( __( 'Install %s', 'portfoliya' ), $label ),
					'action_link'  => add_query_arg(
						array(
							'tab' => 'plugin-information',
							'plugin' => pathinfo( $plugin_id )['filename'],
						),
						admin_url( 'plugin-install.php' )
					),
				);
			}
		}

		return $action;
	}
}
