<?php
/**
 * Content pack and single content linking
 *
 * @package portfoliya
 */

namespace Portfoliya_Pro\Models;

use SolidieLib\_Array;

class PackLink {

	/**
	 * Update relation between single content and content packs
	 *
	 * @param int $content_id
	 * @param array $linking
	 * @return void
	 */
	public static function updateLinking( $content_id, $linking ) {

		global $wpdb;

		foreach ( $linking as $pack_id => $enabled ) {
			$link_id = $wpdb->get_var(
				$wpdb->prepare(
					"SELECT link_id FROM {$wpdb->portfoliya_content_pack_link} WHERE content_id=%d AND pack_id=%s",
					$content_id,
					$pack_id
				)
			);

			if ( empty( $link_id ) ) {
				// Create new entry if not exists
				$wpdb->insert(
					$wpdb->portfoliya_content_pack_link,
					array( 
						'content_id' => $content_id,
						'pack_id'    => $pack_id, 
						'enabled'    => ( bool ) $enabled 
					)
				);

			} else {
				// Update the existing one
				$wpdb->update(
					$wpdb->portfoliya_content_pack_link,
					array( 'enabled' => ( bool ) $enabled ),
					array( 'link_id' => $link_id )
				);
			}
		}
	}

	/**
	 * Get linking for a single content
	 *
	 * @param int $content_id
	 * @return array
	 */
	public static function getLinking( $content_id ) {
		global $wpdb;
		$links = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT pack_id, enabled FROM {$wpdb->portfoliya_content_pack_link} WHERE content_id=%d",
				$content_id
			),
			ARRAY_A
		);

		$new_array = array();
		foreach ( $links as $link ) {
			$new_array[ $link['pack_id'] ] = ( bool ) $link['enabled'];
		}

		return $new_array;
	}
}
