<?php

namespace Portfoliya_Pro\Setup;

use Portfoliya\Main as PortfoliyaMain;
use Portfoliya\Models\AdminSetting;
use Portfoliya_Pro\Main;

class Route {

	/**
	 * The route to capture custom url format
	 */
	const KEY = 'portfoliya-pro-route';

	/**
	 * Route constructor
	 */
	public function __construct() {
		add_filter( 'query_vars', array( $this, 'registerPagename' ) );
		add_action( 'rewrite_rules_array', array( $this, 'rebuildPermalinks' ) );
		add_filter( 'template_include', array( $this, 'registerTemplate' ) );
	}

	/**
	 * Register var
	 *
	 * @param array $vars Query vars
	 *
	 * @return array
	 */
	public function registerPagename( $vars ) {
		$vars[] = self::KEY;
		return $vars;
	}

	/**
	 * Add custom Rewrite rules
	 *
	 * @param array $rules Existing rewrite rules
	 * @return array
	 */
	public function rebuildPermalinks( $rules ) {

		$dashboard_path = AdminSetting::get( 'frontend_dashboard_path' );
		if ( empty( $dashboard_path ) ) {
			return;
		}

		// Register to rules now
		$template  = 'index.php?' . self::KEY . '=' . $dashboard_path;
		$new_rules = array(
			$dashboard_path . '/?$'       => $template,
			$dashboard_path . '/(.+?)/?$' => $template,
		);
		
		return $new_rules + $rules;
	}

	/**
	 * Undocumented function
	 *
	 * @param string $template The template to load
	 * @return string
	 */
	public function registerTemplate( $template ) {

		if ( Dashboard::isFrontDashboard() ) {

			if ( ! is_user_logged_in() ) {
				wp_safe_redirect( wp_login_url( PortfoliyaMain::$configs->current_url ) );
				exit;
			}

			// Load your custom template file here
			$template = Main::$configs->dir . 'templates/frontend-dashboard.php';
		}

		return $template;
	}
}
