<?php

namespace Portfoliya_Pro\Setup;

use Portfoliya\Main as PortfoliyaMain;
use SolidieLib\_Array;
use Portfoliya\Models\AdminSetting;
use Portfoliya\Models\User;
use Portfoliya\Setup\Scripts as SetupScripts;
use Portfoliya_Pro\Helpers\Utilities;
use Portfoliya_Pro\Main;
use Portfoliya_Pro\Models\Contributor;
use WooCommerce as WC;

class Scripts {

	private $cache_version;

	/**
	 * Script loader registration in constructor
	 * 
	 * @return void
	 */
	function __construct() {

		$this->cache_version = 'development' === PortfoliyaMain::$configs->mode ? time() : PortfoliyaMain::$configs->version;

		add_action( 'admin_enqueue_scripts', array( $this, 'loadAdminScripts' ), 10 );
		add_action( 'wp_enqueue_scripts', array( $this, 'frontendScript' ), 10 );
		add_filter( 'portfoliya_frontend_variables', array( $this, 'addProVariables' ) );
	}

	/**
	 * Load admin scripts
	 *
	 * @return void
	 */
	public function loadAdminScripts() {
		// Load resources for only reports page as it uses readymade template
		if ( Utilities::isAdminDashboard( Dashboard::SLUG_REPORTS ) ) {
			
			// Enqueue styles
			wp_enqueue_style( 'portfoliya-reports-google-font', 'https://fonts.googleapis.com/css2?family=Heebo:wght@400;500;600;700&display=swap' );
			wp_enqueue_style( 'portfoliya-reports-fontawesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.10.0/css/all.min.css' );
			wp_enqueue_style( 'portfoliya-reports-bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.4.1/font/bootstrap-icons.css' );
			wp_enqueue_style( 'portfoliya-reports-carousal', Main::$configs->dist_url . 'libraries/reports-resources/lib/owlcarousel/assets/owl.carousel.min.css', array(), Main::$configs->version );
			wp_enqueue_style( 'portfoliya-reports-tempusdominus', Main::$configs->dist_url . 'libraries/reports-resources/lib/tempusdominus/css/tempusdominus-bootstrap-4.min.css', array(), Main::$configs->version );
			wp_enqueue_style( 'portfoliya-reports-bs', Main::$configs->dist_url . 'libraries/reports-resources/css/bootstrap.min.css', array(), Main::$configs->version );
			wp_enqueue_style( 'portfoliya-reports-css', Main::$configs->dist_url . 'libraries/reports-resources/css/style.css', array(), Main::$configs->version );
		
			// Enqueu JS
			wp_enqueue_script( 'portfoliya-reports-bs-jq', 'https://code.jquery.com/jquery-3.4.1.min.js', array(), false, true );
			wp_enqueue_script( 'portfoliya-reports-bs-js', 'https://cdn.jsdelivr.net/npm/bootstrap@5.0.0/dist/js/bootstrap.bundle.min.js', array(), false, true );
			wp_enqueue_script( 'portfoliya-reports-bs-chart', Main::$configs->dist_url . 'libraries/reports-resources/lib/chart/chart.min.js', array(), Main::$configs->version, true );
			wp_enqueue_script( 'portfoliya-reports-bs-easing', Main::$configs->dist_url . 'libraries/reports-resources/lib/easing/easing.min.js', array(), Main::$configs->version, true );
			wp_enqueue_script( 'portfoliya-reports-bs-waypoints', Main::$configs->dist_url . 'libraries/reports-resources/lib/waypoints/waypoints.min.js', array(), Main::$configs->version, true );
			wp_enqueue_script( 'portfoliya-reports-bs-carousal', Main::$configs->dist_url . 'libraries/reports-resources/lib/owlcarousel/owl.carousel.min.js', array(), Main::$configs->version, true );
			wp_enqueue_script( 'portfoliya-reports-bs-moment', Main::$configs->dist_url . 'libraries/reports-resources/lib/tempusdominus/js/moment.min.js', array(), Main::$configs->version, true );
			wp_enqueue_script( 'portfoliya-reports-bs-zone', Main::$configs->dist_url . 'libraries/reports-resources/lib/tempusdominus/js/moment-timezone.min.js', array(), Main::$configs->version, true );
			wp_enqueue_script( 'portfoliya-reports-bs-temdomin', Main::$configs->dist_url . 'libraries/reports-resources/lib/tempusdominus/js/tempusdominus-bootstrap-4.min.js', array(), Main::$configs->version, true );
		}
		
		if ( Utilities::isAdminDashboard() || Dashboard::isFrontDashboard() || Dashboard::isWCOrderPage() ) {
			wp_enqueue_script( 'portfoliya-pro-admin-dashboard-script', Main::$configs->dist_url . 'admin-dashboard-pro.js', array( 'jquery' ), $this->cache_version, true );
		}
	}

	public function frontendScript() {
		if ( Dashboard::isFrontDashboard() ) {
			SetupScripts::loadTinyMCE();
			wp_enqueue_script( 'portfoliya-pro-frontend-dashboard-script', Main::$configs->dist_url . 'frontend-dashboard.js', array( 'jquery' ), $this->cache_version, true );
		}
	}

	/**
	 * Add some pro variables for frontend page
	 *
	 * @param array $variables
	 * @return array
	 */
	public function addProVariables( array $variables ) {

		$settings = AdminSetting::get( 'general' );
		
		// Get contribution settings
		$contribute_models = _Array::getArray( $settings['contribution_distribute_model'] ?? array() );
		$status            = Contributor::getStatus( get_current_user_id() );
		$administrative    = User::hasAdministrativeRole( get_current_user_id() );
		$approval          = ( bool ) ( $settings['public_contributor_approval'] ?? false );
		
		// Add the necessary settings to frontend variables array
		$variables['is_wc_active']                 = class_exists( WC::class );
		$variables['currency_code']                = function_exists( 'get_woocommerce_currency' ) ? get_woocommerce_currency() : '';
		$variables['permalinks']['cart_url']       = function_exists( 'wc_get_cart_url' ) ? wc_get_cart_url() : null;
		$variables['permalinks']['checkout_url']   = function_exists( 'wc_get_checkout_url' ) ? wc_get_checkout_url() : null;
		$variables['permalinks']['dashboard_navs'] = ( object ) apply_filters( 'portfoliya_frontend_dashbord_add_menus', array() );
		$variables['permalinks']['socket_url']     = $settings['socket_server_url'] ?? null;
		$variables['permalinks']['messages_path']  = '/' . Dashboard::getPath( '/messages/' );

		// Contributor configs
		$variables['contribution'] = array(
			'free'                          => $administrative || in_array( 'free', $contribute_models ),
			'paid'                          => $administrative || in_array( 'paid', $contribute_models ),
			'enabled'                       => $administrative || in_array( 'free', $contribute_models ) || in_array( 'paid', $contribute_models ),
			'contributor_status'            => $status,
			'can_contribute'                => $administrative || ! $approval || $status === 'approved',
			'contributor_approval_requires' => $approval
		);

		// Assign some general settings
		$variables['settings']['general'] = array_merge(
			$variables['settings']['general'],
			array(
				'frontend_dashboard_path'            => $settings['frontend_dashboard_path'],
				'public_contribution_deletion'       => $settings['public_contribution_deletion'] ?? false,
				'content_lesson_attachment_supports' => $settings['content_lesson_attachment_supports'],
				'content_lesson_attachment_max_size' => $settings['content_lesson_attachment_max_size'],
				// 'contributor_messaging_enable'       => $settings['contributor_messaging_enable'],
				'daily_contributor_content_limit'    => $settings['daily_contributor_content_limit']
			)
		);
		
		return $variables;
	}
}
