<?php

namespace Portfoliya_Pro\Setup;

class Socket  {

	public function __construct() {
		add_action( 'wp_ajax_nopriv_verifySocketConnection', array( $this, 'verifySocketConnection' ) );
		add_filter( 'portfoliya_frontend_variables', array( $this, 'storeNonce' ), 100 );
		add_filter( 'portfoliya_socket_variables', array( $this, 'storeNonce' ), 100, 2 );
	}

	public function verifySocketConnection() {

		$nonce   = $_POST['nonce'] ?? null;
		$action  = $_POST['nonce_action']?? null;
		$user_id = $_POST['user_id'] ?? null;

		if ( 
			empty( $nonce ) || ! is_string( $nonce ) || 
			empty( $action ) || ! is_string( $action ) ||
			empty( $user_id ) || ( ! is_string( $user_id ) && ! is_numeric( $user_id ) )
		) {
			wp_send_json_error( array( 'message' => __( 'Invalid data', 'portfoliya' ) ) );
		}

		$path         = self::tempDir() . $user_id . $action . $nonce . '.txt';
		$stored_nonce = file_exists( $path ) ? file_get_contents( $path ) : null;

		if ( ! empty( $stored_nonce ) && $nonce === $stored_nonce ) {
			wp_send_json_success();
		} else {
			wp_send_json_error( array( 'message' => __( 'Nonce not matched', 'portfoliya' ) ) );
		}
	}

	private static function tempDir() {
		
		$temp_dir = sys_get_temp_dir();

		if ( substr( $temp_dir, -1 ) !== DIRECTORY_SEPARATOR ) {
			$temp_dir .= DIRECTORY_SEPARATOR;
		}

		return $temp_dir;
	}

	public static function storeNonce( $data, $internal = false ) {

		if ( $internal || is_user_logged_in() ) {
			$user_id = $internal ? $data['user_id'] : get_current_user_id();
			$path = self::tempDir() . $user_id . $data['nonce_action'] . $data['nonce'] . '.txt';
			file_put_contents( $path, $data['nonce'] );
		}

		return $data;
	}
}
