<?php
/**
 * User hooks registrar
 *
 * @package portfoliya
 */

namespace Portfoliya_Pro\Setup;

use Portfoliya\Models\Field;
use Portfoliya_Pro\Models\Message;
use Portfoliya_Pro\Models\Withdrawal;

/**
 * User class
 */
class User {

	public function __construct() {
		add_action( 'delete_user', array( $this, 'processUserDeletion' ), 10, 3 );
		add_action( 'delete_user', array( $this, 'deleteAccount' ) );
	}

	/**
	 * User deletion hook to delete associated data or replace owner
	 *
	 * @param int $id
	 * @param int $reassign
	 * @param object $user
	 * @return void
	 */
	public function processUserDeletion( $id, $reassign, $user ) {

		if ( empty( $reassign ) ) {

			// Delete withdrawals
			Withdrawal::deleteWithdrawalByContributor( $id );
			
		} else {

			// Replace sales
			Field::sales()->updateField( array( 'customer_id' => $reassign ), array( 'customer_id' => $id ) );

			// Replace withdrawals
			Field::withdrawals()->updateField( array( 'contributor_id' => $reassign ), array( 'contributor_id' => $id ) );
		}
	}

	/**
	 * Delete mate user data on deleting user
	 *
	 * @param int $uid
	 * @return void
	 */
	public function deleteAccount( $uid ) {
		Message::deleteByUser( $uid );
	}
}
