<?php
/**
 * App initiator class
 *
 * @package portfoliya
 */

namespace Portfoliya;

use SolidieLib\_Array;
use SolidieLib\Dispatcher;
use SolidieLib\DB;

use Portfoliya\Helpers\Utilities;
use Portfoliya\Setup\OpenGraph;
use Portfoliya\Setup\Scripts;
use Portfoliya\Setup\AdminPage;
use Portfoliya\Setup\Cron;
use Portfoliya\Setup\Media;
use Portfoliya\Setup\Promotion;
use Portfoliya\Setup\Route;
use Portfoliya\Setup\Shortcode;
use Portfoliya\Setup\User;

use Portfoliya\Controllers\ContentController;
use Portfoliya\Controllers\SettingsController;
use Portfoliya\Controllers\CategoryController;
use Portfoliya\Controllers\CommentController;
use Portfoliya\Controllers\LessonController;
use Portfoliya\Models\User as ModelsUser;
use Portfoliya\Setup\Sitemap;

/**
 * Main class to initiate app
 */
class Main {

	/**
	 * Configs array
	 *
	 * @var object
	 */
	public static $configs;

	const ACT_HOOK = 'portfoliya_activated';
	const DB_HOOK = 'portfoliya_db_deployed';

	function __construct() {
		add_action( 'plugins_loaded', array( $this, 'registerControllers' ), 101 );
	}

	/**
	 * Initialize Plugin
	 *
	 * @param object $configs Plugin configs for start up
	 *
	 * @return object
	 */
	public function init( object $configs ) {

		// Store configs in runtime static property
		self::$configs           = $configs;
		self::$configs->dir      = dirname( $configs->file ) . '/';
		self::$configs->basename = plugin_basename( $configs->file );

		// Retrieve plugin info from index
		$manifest      = _Array::getManifestArray( $configs->file, ARRAY_A );
		self::$configs = (object) array_merge( $manifest, (array) self::$configs );

		// Prepare the unique app name
		self::$configs->app_id           = Utilities::getAppId( self::$configs->url );
		self::$configs->sql_path         = self::$configs->dir . 'dist/libraries/db.sql';
		self::$configs->activation_hook  = self::ACT_HOOK;
		self::$configs->db_deployed_hook = self::DB_HOOK;

		// Register Activation/Deactivation Hook
		register_activation_hook( self::$configs->file, array( $this, 'activate' ) );

		// Core Modules
		new DB( self::$configs );
		new Route();
		new Scripts();
		new Shortcode();
		new AdminPage();
		new Media();
		new User();
		new OpenGraph();
		new Cron();
		new Promotion();
		new Sitemap();

		return self::$configs;
	}

	/**
	 * Register controller methods
	 *
	 * @return void
	 */
	public function registerControllers() {

		new Dispatcher(
			self::$configs->app_id,
			array(
				ContentController::class,
				SettingsController::class,
				CategoryController::class,
				CommentController::class,
				LessonController::class,
			)
		);

		add_filter( 
			'portfoliya_controller_roles_' . self::$configs->app_id, 
			function ( $roles ) {
				if ( in_array( 'administrator', $roles ) ) {
					$roles[] = ModelsUser::getPortfoliyaAdminRole();
				}
				return $roles;
			}
		);
	}

	/**
	 * Execute activation hook
	 *
	 * @return void
	 */
	public static function activate() {
		do_action( self::ACT_HOOK );
	}
}
