<?php
/**
 * Manifest
 *
 * @package portfoliya
 */

namespace Portfoliya\Models;

/**
 * Manifest class
 */
class Manifest {
	/**
	 * Get content manifest data
	 *
	 * @return array
	 */
	public static function getManifest() {

		$manifest = array(
			'settings' => array(
				'general'  => array(
					'free_download_label'          => 'Free',
					'free_download_description'    => 'This content is eligible to download for free',
					'enable_content_sitemap'       => true,
					'pagination_contents_per_page' => 20,
					'color_scheme_materials'       => '#236BFE',
					'color_scheme_texts'           => '#1A1A1A',
				),
				'contents' => array(
					// This array will be filled with content types
				),
			),
			'contents' => array(
				'app'      => array(
					'label'       => esc_html__( 'App', 'portfoliya' ),
					'slug'        => 'apps',
					'description' => esc_html__( 'Apps, extensions, addons etc. for website, mobile, computer and so on.', 'portfoliya' ),
					'plans'       => array(),
				),
				'audio'    => array(
					'label'       => esc_html__( 'Audio', 'portfoliya' ),
					'slug'        => 'audios',
					'description' => esc_html__( 'Music, beats, song and so on.', 'portfoliya' ),
					'plans'       => array(),
				),
				'video'    => array(
					'label'       => esc_html__( 'Video', 'portfoliya' ),
					'slug'        => 'videos',
					'description' => esc_html__( 'Vlog, cinematography, film, music videos and so on.', 'portfoliya' ),
					'plans'       => array(),
				),
				'image'    => array(
					'label'       => esc_html__( 'Image', 'portfoliya' ),
					'slug'        => 'images',
					'description' => esc_html__( 'Photography, vector etc.', 'portfoliya' ),
					'plans'       => array(),
				),
				'3d'       => array(
					'label'       => esc_html__( '3D Model', 'portfoliya' ),
					'slug'        => '3d',
					'description' => esc_html__( '3D model, VFX contents, animations and so on.', 'portfoliya' ),
					'plans'       => array(),
				),
				'document' => array(
					'label'       => esc_html__( 'Document', 'portfoliya' ),
					'slug'        => 'documents',
					'description' => esc_html__( 'PDF, Documents, Sheet and so on.', 'portfoliya' ),
					'plans'       => array(),
				),
				'font'     => array(
					'label'       => esc_html__( 'Font', 'portfoliya' ),
					'slug'        => 'fonts',
					'description' => esc_html__( 'Various type of fonts', 'portfoliya' ),
					'plans'       => array(),
				),
				'classified' => array(
					'label'       => esc_html__( 'Classified', 'portfoliya' ),
					'slug'        => 'listings',
					'description' => esc_html__( 'Classified listings', 'portfoliya' ),
					'plans'       => array(),
				),
				'tutorial' => array(
					'label'       => esc_html__( 'Tutorial', 'portfoliya' ),
					'slug'        => 'tutorials',
					'description' => esc_html__( 'Full fledged tutorial management system.', 'portfoliya' ),
					'plans'       => array(),
				),
			),
		);

		// Add the content type array in content settings
		foreach ( array_keys( $manifest['contents'] ) as $type ) {
			$manifest['settings']['contents'][ $type ] = array(
				'label'                 => $manifest['contents'][ $type ]['label'],
				'slug'                  => $manifest['contents'][ $type ]['slug'],
				'enable'                => false,
				'show_thumbnail'        => true,
				'enable_comment'        => true,
				'show_contributor_info' => true,
				'reaction_type'         => 'like',
			);
		}

		// Finally return the manifest
		return apply_filters( 'portfoliya_manifest', $manifest );
	}

	/**
	 * Get content type label
	 *
	 * @param string $content_type The content type get label for
	 * @param bool   $default The fallback to return
	 *
	 * @return string
	 */
	public static function getContentTypeLabel( $content_type, $default = null ) {
		$content_type = self::getManifest()['contents'][ $content_type ] ?? array();
		return $content_type['label'] ?? $default;
	}
}
