<?php
/**
 * Media manager class
 *
 * @package portfoliya
 */

namespace Portfoliya\Setup;

use Portfoliya\Models\AdminSetting;
use Portfoliya\Models\FileManager;

/**
 * Media
 */
class Media {
	/**
	 * Register media hooks
	 *
	 * @return void
	 */
	public function __construct() {
		add_action( 'pre_get_posts', array( $this, 'hideMedia' ) );
		add_filter( 'portfoliya_get_content_download_link', array( $this, 'provideDownloadLink' ), 10, 2 );
	}

	public function provideDownloadLink( $url, $content_slug ) {
		return FileManager::getMediaLink( 0, array( 'content_slug' => $content_slug ) );
	}

	/**
	 * Hide contents from WP media view
	 *
	 * @param object $query The query object to hide media thorough
	 * @return void
	 */
	public function hideMedia( $query ) {

		// Only modify the query for media contents
		if ( is_admin() && 'attachment' === $query->query['post_type'] ) {
			$meta_query = $query->get( 'meta_query' );
			if ( ! is_array( $meta_query ) ) {
				$meta_query = array();
			}

			$meta_query[] = array(
				'key'     => FileManager::SOLIDIE_FILE_IDENTIFIER_META_KEY,
				'compare' => 'NOT EXISTS', // Hide release media contents
			);

			$query->set( 'meta_query', $meta_query );
		}
	}
}
