import React, { useContext, useState } from "react";

import { __, data_pointer, sprintf } from "solidie-materials/helpers.jsx";
import { Modal } from "solidie-materials/modal.jsx";
import { request } from "solidie-materials/request.jsx";
import { ContextToast } from "solidie-materials/toast/toast.jsx";
import { LoadingIcon } from "solidie-materials/loading-icon/loading-icon.jsx";

import { ItemSingle, getNewPlan } from "./plan-settings.jsx";

const {is_admin} = window[data_pointer];

export function AddPlan({content_type, onAdd, sales_model='single'}) {

	const {ajaxToast} = useContext(ContextToast);

	const [state, setState] = useState({
		plan: {},
		new_plan_modal: false,
		submitting: false,
	});

	const [hookDock, setHookDoc] = useState(false);

	const setVal=(name, value)=>{
		setState({
			...state,
			plan: {
				...state.plan,
				[name]: value
			}
		});
	}

	const toggleModal=()=>{
		
		const {new_plan_modal} = state;
		const show = !new_plan_modal;

		setState({
			...state,
			plan: show ? {...getNewPlan(), sales_model} : null,
			new_plan_modal: show
		});
	}

	const submitPlan=()=>{
		
		setState({
			...state,
			submitting: true
		});

		request('addStandalonePlan', {content_type, plan: state.plan}, resp=>{

			setState({
				...state,
				submitting: false,
				new_plan_modal: !resp.success
			});

			if ( ! resp.success ) {
				ajaxToast(resp);
			} else {
				onAdd();
			}
		});
	}

	return <div>
		{
			!state.new_plan_modal ? null :
			<Modal onClose={toggleModal}>
				<div style={{padding: '10px 7px'}}>
					<strong className={'d-block font-size-24 font-weight-500 margin-bottom-10'.classNames()}>
						{state.plan?.sales_model==='single' ? __('Add New Plan') : __('Add New Bundle')}
					</strong>
					<i className={'d-block font-size-13 margin-bottom-20 color-text-60'.classNames()}>
						{sprintf(__('Note: You are going to create a reusable plan that can be enabled/disabled and customized per %s. Global plans can be configured in settings.'), content_type)}
					</i>

					<div className={'margin-bottom-20 font-weight-400'.classNames()}>
						<ItemSingle
							plan={state.plan}
							standalone={true}
							content_type={content_type}
							editPlan={setVal}
						/>
					</div>
					<div className={'d-flex align-items-center justify-content-flex-end column-gap-15'.classNames()}>
						<button 
							className={'button button-outlined button-small'.classNames()} 
							onClick={toggleModal}
							disabled={state.submitting}
						>
							{__('Cancel')}
						</button>
						<button 
							className={'button button-primary button-small'.classNames()} 
							onClick={submitPlan}
							disabled={state.submitting}
						>
							{__('Add')} <LoadingIcon show={state.submitting}/>
						</button>
					</div>
				</div>
			</Modal>
		}

		<div className={'d-flex align-items-center justify-content-space-between'.classNames()}>
			<span 
				className={'cursor-pointer hover-underline color-material-90'.classNames()}
				onClick={toggleModal}
			>
				{sales_model==='single' ? __('+ Add New Plan') : __('+ Add New Bundle')}
			</span>
			{
				!is_admin ? null :
				<i 
					className={`sicon ${!hookDock ? 'sicon-circle-info' : 'sicon-times'} font-size-16 color-text-90 cursor-pointer interactive`.classNames()}
					onClick={()=>setHookDoc(!hookDock)}
				></i>
			}
		</div>

		{
			!hookDock ? null :
			<div style={{borderRadius: '5px', border: '1px solid lightgray', padding: '10px', marginTop: '5px', lineHeight: '26px'}}>
				<code>apply_filters( 'portfoliya_get_content_plans', array(), string $content_slug, bool $enabled_only );</code> to get plans and utilize in custom way. 
			</div>
		}
	</div>
}
