import React from "react";
import { Navigate, HashRouter, Route, Routes, useNavigate, useParams } from "react-router-dom";

import { WpDashboardFullPage } from "solidie-materials/backend-dashboard-container/full-page-container.jsx";
import { Tabs } from "solidie-materials/tabs/tabs.jsx";
import { __ } from "solidie-materials/helpers.jsx";

import { ReportsOverview } from "./overview/reports-overview.jsx";
import { SalesReports } from "./sales/sales-reports.jsx";

const tabs = {
	overview: {
		label: __('Overview'),
		component: ReportsOverview
	},
	sales: {
		label: __('Sales'),
		component: SalesReports
	}
}

function Wrapper() {
	
	const navigate = useNavigate();
	const {sub_path='overview'} = useParams();
	const Comp = tabs[sub_path]?.component;

	return  <div className={`height-p-100`.classNames()} style={{padding: '1.5rem'}}>
		<div className={'margin-bottom-15'.classNames()} style={{width: '200px'}}>
			<Tabs
				theme="button"
				active={sub_path}
				onNavigate={(active_tab) => navigate(`/reports/${active_tab}/`)}
				tabs={Object.keys(tabs).map(k=>{
					return {
						id: k, 
						label: tabs[k].label
					}
				})}
			/> 
		</div>
		
		{Comp ? <Comp/> : __('Invalid Component')}
	</div>
}

export function ReportsPage() {
	return <WpDashboardFullPage>
		<HashRouter>
			<Routes>
				<Route path="/reports/:sub_path?/:data_id?/" element={<Wrapper/>}/>
				<Route path={'*'} element={<Navigate to="/reports/overview/" replace />}/>
			</Routes>
		</HashRouter>
	</WpDashboardFullPage>
}
