import React, { useContext } from "react";
import { Link, useLocation } from "react-router-dom";

import { __, data_pointer, getDashboardPath } from "solidie-materials/helpers.jsx";
import {confirm} from 'solidie-materials/prompts.jsx';

import { ContextSocket } from "../../socket-wrapper";

import * as style from './sidebar.module.scss';
import * as layout from '../../style.module.scss';

export function Sidebar({ navs, toggleSidebar }) {

	const location = useLocation();
	const {stats: socket_stats={}} = useContext(ContextSocket);

	// Determine current root menu path
	const path_root = location.pathname.split('/').filter(l=>l).join('/');
	const dashboard_root = getDashboardPath('').split('/').filter(l=>l).join('/');
	const rel_path = path_root.replace(dashboard_root, '').split('/').filter(l=>l)[0];

	const {
		permalinks: {
			home_url,
			logout,
			dashboard_navs={}
		}
	} = window[data_pointer];

	return <ul className={"navList".classNames(layout) + 'sidebar'.classNames(style)}>

		{/* Show menus registered in JS run time */}
		{navs.map(menu=>{
			
			let {
				text: label, 
				path, 
				icon, 
				show_menu=true,
				socket_stat
			} = menu;

			const url       = getDashboardPath(path);
			const _path     = path.split('/').filter(l=>l)[0];
			const is_active = _path === rel_path;
			const show_dot = socket_stat && socket_stats[socket_stat];

			return !show_menu ? null : <li key={path}>
				<div 
					className={("navList__subheading row-appstore singular" +(is_active ? ' navList__subheading--open' : '')).classNames(layout)} 
					onClick={()=>toggleSidebar(false)}
				>
					<Link to={url}>
						<span className={"navList__subheading-title".classNames(layout) + 'd-flex align-items-center column-gap-8 position-relative'.classNames()}>
							<span>{label}</span> {show_dot ? <span className={'red-dot'.classNames(style)}></span> : null}
						</span>
					</Link>
				</div>
			</li>
		})}
		
		{/* Show menus registered from backend server */}
		{
			Object.keys(dashboard_navs).map(key=>{
				
				const {label, url} = dashboard_navs[key];

				return <li key={key}>
					<div 
						className={"navList__subheading row-appstore singular".classNames(layout)} 
						onClick={()=>toggleSidebar(false)}
					>
						<a 
							href={url}
						>
							<span className={"navList__subheading-title".classNames(layout)}>
								{label}
							</span>
						</a>
					</div>
				</li>
			})
		}
		
		{/* Show logout menu */}
		<li>
			<div 
				className={"navList__subheading row-appstore singular".classNames(layout)} 
			>
				<a 
					href='#'
					onClick={e=>{
						e.preventDefault();
						confirm(
							__('Sure to logout?'),
							()=>{
								window.location.replace(logout)
							}
						);
					}}
				>
					<span className={"navList__subheading-title".classNames(layout)}>
						{__('Logout')}
					</span>
				</a>
			</div>
		</li>
	</ul>
};
