import React from "react";
import { __, data_pointer } from "solidie-materials/helpers.jsx";
import { useState } from "react";
import { request } from "solidie-materials/request";
import { useContext } from "react";
import { ContextToast } from "solidie-materials/toast/toast.jsx";
import { LoadingIcon } from "solidie-materials/loading-icon/loading-icon";
import {confirm} from 'solidie-materials/prompts.jsx';

const {
	contribution: {
		contributor_status
	}
} = window[data_pointer];

const prompts = {
	pending: __('Apply for contribution?'),
	'': __('Cancel the application?'),
}

function Wrapper({children}) {
	return <div style={{padding: '25px', marginTop: '50px'}}>
		<div style={{maxWidth: '600px', margin: '0 auto', background: 'white', borderRadius: '15px', padding: '40px 30px'}} className={'box-shadow-thin'.classNames()}>
			{children}
		</div> 
	</div>
}

export function ContributionApplication() {

	const {ajaxToast} = useContext(ContextToast);
	const [loading, setLoading] = useState(false);
	const [currentStatus, setCurrentStatus] = useState(contributor_status);

	const changeStatus=(status)=>{

		confirm(
			prompts[status],
			()=>{
				setLoading(true);

				request('updateContributorStatus', {status}, resp=>{

					const {
						success,
						data: {
							contributor_status=currentStatus
						}
					} = resp;

					if ( ! success ) {
						ajaxToast(resp);
					}
					
					setLoading(false);
					setCurrentStatus(contributor_status);
				});
			}
		);
	}

	if ( currentStatus === 'pending' ) {
		return <Wrapper>
			<div className={'text-align-center'.classNames()}>
				<strong className={'d-block font-size-20 font-weight-400 color-warning margin-bottom-15'.classNames()}>
					{__('Your contributor application is currently awaiting approval.')}
				</strong>

				<button 
					className={'button button-primary button-outlined'.classNames()}
					disabled={loading}
					onClick={()=>changeStatus('')}
				>
					{__('Cancel Request!')} <LoadingIcon show={loading}/>
				</button>
			</div> 
		</Wrapper> 
	}

	if ( currentStatus === 'rejected' ) {
		return <Wrapper>
			<strong className={'d-block text-align-center font-size-20 font-weight-400 color-error'.classNames()}>
				{__('Unfortunately, your contributor application has not been approved.')}
			</strong>
		</Wrapper> 
	}
	
	if ( currentStatus === 'banned' ) {
		return <Wrapper>
			<strong className={'d-block text-align-center font-size-20 font-weight-400 color-error'.classNames()}>
				{__('Your contributor status has been revoked.')}
			</strong>
		</Wrapper> 
	}
	
	return <Wrapper>
		<div className={'text-align-center'.classNames()}>
			<strong className={'d-block font-size-20 font-weight-400 margin-bottom-20'.classNames()}>
				{__('Are you interested in becoming a contributor?')}
			</strong>

			<button 
				className={'button button-primary'.classNames()}
				disabled={loading}
				onClick={()=>changeStatus('pending')}
				data-cylector="apply-now"
			>
				{__('Apply now!')} <LoadingIcon show={loading}/>
			</button>
		</div>
	</Wrapper> 
}
