import React, { useEffect, useState } from "react";
import { Link, useParams } from "react-router-dom";

import { request } from "solidie-materials/request.jsx";
import { __, currency_symbol, formatDate } from "solidie-materials/helpers.jsx";
import { TableStat } from "solidie-materials/table-stat.jsx";
import { InitState } from "solidie-materials/init-state.jsx";
import { order_statuses } from "solidie-materials/data.jsx";

import { OrderDetails } from "./order-details.jsx";

export function MyOrders() {

	const {order_id} = useParams();

	const [state, setState] = useState({
		fetching: true,
		error_message: null,
		orders: []
	});

	const getOrders=()=>{

		setState({
			...state,
			fetching: true
		});

		request('getMyOrders', {}, resp=>{
			const {
				success,
				data: {
					orders=[],
					message=__('Something went wrong!')
				}
			} = resp;

			setState({
				fetching: false,
				error_message: success ? null : message,
				orders: success ? orders : state.orders
			});
		});
	}

	useEffect(()=>{
		getOrders();
	}, []);

	if ( state.fetching || state.error_message ) {
		return <InitState 
			fetching={state.fetching} 
			error_message={state.error_message}
		/>
	}

	if ( order_id  ) {
		return <OrderDetails 
			order={state.orders.find(o=>o.order_id==order_id)}
		/>
	}

	return <div>
		<table className={'table '.classNames()}>
			<thead>
				<tr>
					<th>{__('Order')}</th>
					<th>{__('Date')}</th>
					<th>{__('Status')}</th>
					<th>{__('Total')}</th>
				</tr>
			</thead>
			<tbody>
				{
					state.orders.map(order=>{
						return <tr key={order.order_id}>
							<td data-th={__('Order')}>
								<Link 
									to={order.order_id.toString()} 
									className={'color-material-80 interactive'.classNames()}
									data-cylector="order-single-link"
								>
									#{order.order_id}
								</Link>
							</td>
							<td data-th={__('Date')}>
								{formatDate(order.order_date?.date)}
							</td>
							<td data-th={__('Status')}>
								{order_statuses[order.order_status] || order.order_status}
							</td>
							<td data-th={__('Total')}>
								{currency_symbol}{order.order_total}
							</td>
						</tr>
					})
				}
				<TableStat 
					empty={!state.orders?.length}
					loading={state.fetching}
					message={state.error_message || __('No order yet!')}
				/>
			</tbody>
		</table>
	</div>
}