import React from "react";

import { isEmpty, sprintf, __, currency_symbol, getBack, getDashboardPath } from "solidie-materials/helpers.jsx";
import { Link } from "react-router-dom";

export function OrderDetails({order}) {
	
	return <div style={{maxWidth: '750px', margin: '30px auto'}}>

		<strong className={'d-flex align-items-center column-gap-8 margin-bottom-10'.classNames()}>
			<Link 
				to={getDashboardPath('my-orders')} 
				onClick={getBack} 
				className={'sicon sicon-arrow-left font-size-24'.classNames()}
			/>
			
			<span className={'color-text-80 font-size-24 font-weight-600'.classNames()}>
				{sprintf(__('Order #%s'), order.order_id)}
			</span>
		</strong>

		{
			isEmpty( order ) ? 
			<div className={'color-error'.classNames()}>
				{__('Order not found!')}
			</div>
			:
			<table className={'table vertical-head'.classNames()} data-cylector="order-details-table">
				<thead>
					<tr>
						<th>{__('Items')}</th>
						<th>{__('Sub Total')}</th>
						<th>{__('Total')}</th>
						<th>{__('Payment Method')}</th>
						<th>{__('Billing Address')}</th>
						{
							!order.shipping_address ? null :
							<th>{__('Shipping Address')}</th>
						}
					</tr>
				</thead>
				<tbody>
					<tr>
						<td data-th={__('Items')}>
							<div style={{display: 'grid', gridTemplateColumns: 'auto auto auto', gap: '15px'}}>
								{
									order.items.map(item=>{
										return <React.Fragment key={item.id}>
											<div>
												{item.name}
											</div>
											<div>
												x{item.quantity}
											</div>
											<div>
												{currency_symbol}{item.subtotal}
											</div>
										</React.Fragment>
									})
								}
							</div>
						</td>

						<td data-th={__('Subtotal')}>
							{currency_symbol}{order.order_subtotal}
						</td>

						<td data-th={__('Total')}>
							{currency_symbol}{order.order_total}
						</td>

						<td data-th={__('Payment Method')}>
							<div dangerouslySetInnerHTML={{__html: order.payment_method}}></div>
						</td>

						{
							!order.billing_address ? null :
							<td data-th={__('Billing Address')}>
								<div className={'line-height-26'.classNames()}>
									<div dangerouslySetInnerHTML={{__html: order.billing_address}}></div>
									
									<a href={`tel:${order.billing_phone}`} className={'d-block color-material-80 interactive'.classNames()}>
										{order.billing_phone}
									</a>

									<a href={`mailto:${order.billing_email}`} className={'d-block color-material-80 interactive'.classNames()}>
										{order.billing_email}
									</a>
								</div>
							</td>
						}

						{
							!order.shipping_address ? null :
							<td data-th={__('Shipping Address')}>
								<div className={'line-height-26'.classNames()}>
									<div dangerouslySetInnerHTML={{__html: order.shipping_address}}></div>
								</div>
							</td>
						}
					</tr>
				</tbody>
			</table>
		}
	</div> 
}
