import React, { useContext, useState } from "react";

import { __, data_pointer, isEmpty } from "solidie-materials/helpers.jsx";
import { TextField } from "solidie-materials/text-field/text-field.jsx";
import { LoadingIcon } from "solidie-materials/loading-icon/loading-icon";
import { request } from "solidie-materials/request";
import { ContextToast } from "solidie-materials/toast/toast";

const fields=[
	{
		name: 'first_name',
		label: __('First Name')
	},
	{
		name: 'last_name',
		label: __('Lat Name')
	},
	{
		name: 'display_name',
		label: __('Preferred Name')
	}
];

const {readonly_mode} = window[data_pointer];

export function AccountSettings() {

	const {user: {first_name, last_name, display_name}} = window[data_pointer];

	const {ajaxToast} = useContext(ContextToast);

	const [state, setState] = useState({
		has_changes: false,
		saving: false,
		values: {
			first_name, 
			last_name, 
			display_name
		}
	});

	const invalids = fields.filter(field=>isEmpty(state.values[field.name]));

	const onChange=(name, value)=>{
		setState({
			...state,
			has_changes: true,
			values: {
				...state.values,
				[name]: value
			}
		});
	}

	const saveChanges=()=>{
		
		setState({
			...state,
			saving: true
		});
		
		request('updateUserInfo', state.values, resp=>{

			if ( resp.success ) {

				window[data_pointer].user = {
					...window[data_pointer].user,
					first_name: state.values.first_name,
					last_name: state.values.last_name,
					display_name: state.values.display_name,
				}
			}

			ajaxToast(resp);

			setState({
				...state,
				saving: false
			});
		});
	}

	return <div>
		{
			fields.map(field=>{

				const {name, type='text', label} = field;

				return <div 
					key={field.name} 
					style={{marginBottom: '25px'}}
				>
					{
						'text' !== type ? null :
						<div>
							<label className={"d-block font-size-16 margin-bottom-5 color-text-80 font-weight-500".classNames()}>
								{label}<span className={'color-error'.classNames()}>*</span>
							</label>
							<TextField 
								type={type}
								value={state.values[name] || ''}
								onChange={v=>onChange(name, v)}
							/>
						</div>
					}
				</div>
			})
		}

		<div className={'text-align-right'.classNames()}>
			<button
				disabled={readonly_mode || !state.has_changes || state.saving || invalids.length}
				onClick={saveChanges}
				className={'button button-primary'.classNames()}
			>
				{__('Update')} <LoadingIcon show={state.saving}/>
			</button>
		</div>
	</div>
}
