import React, { useContext, useState } from "react";

import { __, data_pointer, isEmpty } from "solidie-materials/helpers.jsx";
import { TextField } from "solidie-materials/text-field/text-field.jsx";
import { LoadingIcon } from "solidie-materials/loading-icon/loading-icon";
import { request } from "solidie-materials/request";
import { ContextToast } from "solidie-materials/toast/toast";

const fields = [
	{
		name: 'current_password',
		type: 'password',
		label: __('Current Password'),
	},
	{
		name: 'new_password',
		type: 'password',
		label: __('New Password'),
	},
	{
		name: 'retype_password',
		type: 'password',
		label: __('Retype New Password'),
	}
];

const {readonly_mode} = window[data_pointer];

export function PasswordChange() {

	const {ajaxToast} = useContext(ContextToast);

	const [state, setState] = useState({
		has_changes: false,
		saving: false,
		values: {}
	});

	const invalids = fields.filter(field=>isEmpty(state.values[field.name]));

	const onChange=(name, value)=>{
		setState({
			...state,
			has_changes: true,
			values: {
				...state.values,
				[name]: value
			}
		});
	}

	const saveChanges=()=>{
		
		setState({
			...state,
			saving: true
		});
		
		request('updateUserPass', state.values, resp=>{

			ajaxToast(resp);

			if ( resp.success ) {
				window.location.reload();
				return;
			}
			
			setState({
				...state,
				saving: false
			});
		});
	}

	return <div>
		{
			fields.map(field=>{

				const {name, type='text', label} = field;
				const value = state.values[name] || '';
				const show_tick = name == 'retype_password' && ! isEmpty(value) && value===state.values.new_password;

				return <div 
					key={field.name} 
					style={{marginBottom: '25px'}}
				>
					{
						['text', 'password'].indexOf(type)===-1 ? null :
						<div>
							<label className={"d-flex align-items-center column-gap-8 margin-bottom-5 color-text-80".classNames()}>
								<span className={'font-size-16 font-weight-500'.classNames()}>
									{label}
								</span>
								{
									!show_tick ? 
									<span className={'color-error'.classNames()}>*</span> : 
									<input type="radio" checked={true} style={{cursor: 'default'}}/>
								}
							</label>
							<TextField 
								type={type}
								value={value}
								onChange={v=>onChange(name, v)}
								password_strength={name=='new_password'}
							/>
						</div>
					}
				</div>
			})
		}

		<div className={'d-flex align-items-center'.classNames()}>
			<div className={'flex-1'.classNames()}>
				<span className={'color-warning'.classNames()}>
					<small>
						<i>
							{__('You will be logged out after changing password.')}
						</i>
					</small>
				</span>
			</div>
			<div>
				<button
					disabled={readonly_mode || !state.has_changes || state.saving || invalids.length || (state.values.new_password!=state.values.retype_password)}
					onClick={saveChanges}
					className={'button button-primary'.classNames()}
				>
					{__('Update')} <LoadingIcon show={state.saving}/>
				</button>
			</div>
		</div>
	</div>
}
