import React from "react";
import { useNavigate, useParams } from "react-router-dom";

import { __, data_pointer, getDashboardPath } from "solidie-materials/helpers.jsx";
import { Tabs } from "solidie-materials/tabs/tabs.jsx";

import { AccountSettings } from "./account-settings.jsx";
import { WithdrawalSetting } from "./withdrawal-method.jsx";
import { PasswordChange } from "./password.jsx";

const tabs = {
	account: {
		label: __('Account'),
		component: AccountSettings
	},
	password: {
		label: __('Password'),
		component: PasswordChange
	}
}

// Add withdrawal method if can contribute and publish paid content
const {
	contribution:{
		can_contribute, 
		paid
	}, 
	settings:{
		contents: manifest_contents={}
	}
} = window[data_pointer];
export const has_purchasable = Object.keys(manifest_contents).filter(type=>manifest_contents[type].purchasable && manifest_contents[type].enable).length;

if ( can_contribute && paid && has_purchasable ) {
	tabs.withdrawal = {
		label: __('Withdrawal Method'),
		component: WithdrawalSetting
	}
}

export function SettingsPage() {

	const {active_tab='account'} = useParams();
	const Comp = (tabs[active_tab] || tabs.account).component;

	const navigate = useNavigate();
	const tab_keys = Object.keys(tabs);

	return <div style={{maxWidth: '600px', margin: 'auto'}}>
		
		<div style={{marginBottom: '25px'}}>
			{
				tab_keys.length>1 ?
				<Tabs
					onNavigate={t=>navigate(getDashboardPath(`settings/${t}/`))} 
					active={active_tab} 
					theme='transparent'
					tabs = {
						Object.keys(tabs).map(k=>{
							return {
								id: k,
								label: tabs[k].label
							}
						})
					}
				/>
				:
				<span className={'font-size-24 font-weight-600'.classNames()}>
					{tabs[tab_keys[0]]?.label}
				</span>
			}
		</div>
		
		<Comp/>
	</div>
}
