import React, { useContext, useState } from "react";
import { Link } from "react-router-dom";

import {confirm} from 'solidie-materials/prompts.jsx';
import { __, formatDate } from "solidie-materials/helpers.jsx";
import { request } from "solidie-materials/request.jsx";
import { TableStat } from "solidie-materials/table-stat.jsx";
import { ContextToast } from "solidie-materials/toast/toast.jsx";

export function Wishlist() {

	const {ajaxToast} = useContext(ContextToast);
	
	const [state, setState] = useState({
		fetching: true,
		wishlist: []
	});

	const getWishlists=()=>{
		setState({
			...state,
			fetching: true
		});

		request('getWishlist', {}, resp=>{
			setState({
				...state,
				fetching: false,
				wishlist: resp.data.wishlist
			})
		});
	}

	const removeFromWishlist=(content_id)=>{
		
		confirm(
			__('Remove from wishlist?'),
			()=>{
				request('reactToContent', {content_id, reaction: -1, reaction_type: 'wishlist'}, resp=>{
					if ( ! resp.success ) {
						ajaxToast(resp);
						return;
					}

					getWishlists();
				});
			}
		);
	}

	useState(()=>{
		getWishlists();
	}, []);

	return <div className={'padding-5'.classNames()}>
		<table className={'table '.classNames()}>
			<thead>
				<tr>
					<th>{__('Item')}</th>
					<th>{__('Date Added')}</th>
					<th>{__('Action')}</th>
				</tr>
			</thead>
			<tbody>
				{
					state.wishlist.map(item=>{
						return <tr key={item.reaction_id}>
							<td data-th={__('Item')}>
								<div className={'d-flex align-items-center column-gap-15'.classNames()}>
									<img 
										src={item.media?.thumbnail?.file_url}
										style={{width: '40px', height: 'auto'}}
									/>

									<Link 
										to={item.content_permalink || '#'} 
										target="_blank"
										className={'font-size-16 font-weight-400 color-text-90 interactive'.classNames()}
									>
										{item.content_title}
									</Link>
								</div>
							</td>
							<td data-th={__('Date Added')}>
								{formatDate(item.reaction_date)}
							</td>
							<td data-th={__('Action')}>
								<span 
									className={'hover-underline cursor-pointer color-error'.classNames()}
									onClick={()=>removeFromWishlist(item.content_id)}
									data-cylector="remove-from-wishlist"
								>
									{__('Remove')}
								</span>
							</td>
						</tr>
					})
				}
				<TableStat 
					empty={!state.wishlist.length} 
					loading={state.fetching}
					message={__('No items saved yet')}
				/>
			</tbody>
		</table>
	</div>
}